Lighthouse has a new layout. Prefer the old one? Return to the old layout, and switch back any time from the link at the top of each page.

Changeset [2e5081b137dd575a9a6a80a7098b3fcba9a3e9d4] by Alexander Ljungberg

Revision 2e5081b137dd575a9a6a80a7098b3fcba9a3e9d4, committed by Alexander Ljungberg · May 27th, 2011 @ 08:02 PM

Optimise array controller addObject: by eliminating entirely pointless rearrange when added objects did not pass the filter. Also avoided double rearrange if clearsFilterPredicateOnInsertion.

CPArrayControllerPerformance.j execution time on "testAddObject_, sorted, filtered" down from ~420ms to ~60ms on my machine.
https://github.com/280north/cappuccino/commit/2e5081b137dd575a9a6a8...

2 changed files

  • M AppKit/CPArrayController.j
  • M Tests/AppKit/CPArrayControllerPerformance.j